//=============================================================================
//    S E N S I R I O N   AG,  Laubisruetistr. 50, CH-8712 Staefa, Switzerland
//=============================================================================
/// \file    sdp3x.h (V1.0)
/// \author  RFU
/// \date    17-Aug-2016
/// \brief   Sensor Layer: Definitions of commands and functions for sensor
///                        access.
//=============================================================================

#ifndef SDP3X_H
#define SDP3X_H

#include "system.h"

//-----------------------------------------------------------------------------
/// \brief Enumeration to configure the temperature compensation for
///        measurement.
typedef enum {
  SDP3X_TEMPCOMP_MASS_FLOW,
  SDP3X_TEMPCOMP_DIFFERNTIAL_PRESSURE
} Sdp3xTempComp;

//-----------------------------------------------------------------------------
/// \brief Enumeration to configure the averaging for measurement.
typedef enum {
  SDP3X_AVERAGING_NONE,
  SDP3X_AVERAGING_TILL_READ
} Sdp3xAveraging;

//-----------------------------------------------------------------------------
/// \brief  Initializes the I2C bus for communication with the sensor.
/// \param  i2cAddress  Sensors I2C address.
void Sdp3x_Init(uint8_t i2cAddress);

//-----------------------------------------------------------------------------
/// \brief  Starts the continous mesurement with the specified settings.
/// \param  tempComp  Temperature compensation: Mass flow or diff. pressure.
/// \param  averaging Averaging: None or average till read.
/// \return ERROR_NONE              = No error.
///         ERROR_ACK               = No acknowledgment from sensor.
///         ERROR_INVALID_PARAMETER = At least one of the specified parameter
///                                   are invalid.
Error Sdp3x_StartContinousMeasurement(Sdp3xTempComp  tempComp,
                                      Sdp3xAveraging averaging);

//-----------------------------------------------------------------------------
/// \brief  Stops the continous mesurement.
/// \return ERROR_NONE              = No error.
///         ERROR_ACK               = No acknowledgment from sensor.
Error Sdp3x_StopContinousMeasurement(void);

//-----------------------------------------------------------------------------
/// \brief  Reads the measurment result from the continous measurment.
/// \param  diffPressure Pointer to return the measured diverential pressur.
///         temperature  Pointer to return the measured temperature.
/// \return ERROR_NONE              = No error.
///         ERROR_ACK               = No acknowledgment from sensor.
///         ERROR_CHECKSUM          = Checksum does not match.
Error Sdp3x_ReadMeasurementResults(float* diffPressure, float* temperature);

//-----------------------------------------------------------------------------
/// \brief  Calls the soft reset mechanism that forces the sensor into a
///         well-defined state without removing the power supply.
/// \return ERROR_NONE              = No error.
///         ERROR_ACK               = No acknowledgment from sensor.
Error Sdp3x_SoftReset(void);

#endif /* SDP3X_H */
